@@ -3,10 +3,7 @@
  *
  * Copyright (C) 2010 Creytiv.com
  */
-#ifdef CYGWIN
-#include <ws2tcpip.h>
-#include <winsock2.h>
-#elif defined(WIN32)
+#if defined(WIN32)
 #include <winsock2.h>
 #include <ws2tcpip.h>
 #else
@@ -129,9 +126,3 @@ void net_conn_stop(void);
 /* Net strings */
 const char *net_proto2name(int proto);
 const char *net_af2name(int af);
-
-
-/* todo: this does not really belong here.. */
-#ifdef __SYMBIAN32__
-int kerr2errno(int kerr);
-#endif
